Referrer Policy controls the behavior of the Referer header, which indicates the origin or web page URL the request was
made from. The web application uses an insecure Referrer Policy configuration that may leak user information to
third-party sites.
